import java.io.File;
import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.Scanner;

public class Text {

    private ArrayList<String> text = new ArrayList<>();
    private static final String dummyTextFileName = "dummytext.txt";
    private static String dummyText = "";


    /**
     * Static block to get Dummytext from file.
     */
    static {
        File dummyTextFile = new File(dummyTextFileName);
        try {
            Scanner scanner = new Scanner(dummyTextFile);
            while(scanner.hasNextLine()) {
                dummyText = dummyText + scanner.nextLine() + " ";
            }
        } catch (FileNotFoundException e) {
            dummyText = "File " + dummyTextFileName + " not found.";
        }
    }


    /**
     * Method to add a paragraph at a specific position.
     * @param paragraphNumber number of paragraph where the new text should be added
     * @param text the Text which should be added.
     * @return returns true if the given paragraph exists and is added successfully
     */
    public boolean add(int paragraphNumber, String text) {
        if(paragraphNumber > 0 && (paragraphNumber <= this.text.size())) {
            this.text.add((paragraphNumber - 1), text);
            return true;
        }
        return false;
    }

    /**
     * Method to add a paragraph at the end of the existing text.
     * @param text the Text which should be added.
     * @return returns true if the paragraph is added successfully
     */
    public boolean add(String text) {
        this.text.add(text);
        return true;
    }

    /**
     * Method to add a dummy text paragraph at a specific position.
     * @param paragraphNumber number of paragraph where the dummy text should be added
     * @return returns true if the given paragraph exists and is added successfully
     */
    public boolean dummy(int paragraphNumber) {
        return add(paragraphNumber, dummyText);
    }

    /**
     * Method to add a dummy text paragraph at the end of the existing text.
     * @return returns true if the paragraph is added successfully
     */
    public boolean dummy() {
        return add(dummyText);
    }

    /**
     * Method to replace characters in a specific paragraph
     * @param paragraphNumber number of paragraph which should be changed.
     * @param oldChar the old character.
     * @param newChar the new character.
     * @return returns true if the given paragraph exists and is changed successfully
     */
    public boolean replace(int paragraphNumber, String oldChar, String newChar) {
        if(paragraphNumber > 0 && (paragraphNumber <= this.text.size())) {
            text.set((paragraphNumber - 1), text.get(paragraphNumber - 1).replace(oldChar, newChar));
            return true;
        }
        return false;
    }

    /**
     * Method to replace characters in the last paragraph
     * @param oldChar the old character.
     * @param newChar the new character.
     * @return returns true if the paragraph is changed successfully
     */
    public boolean replace(String oldChar, String newChar) {
        text.set((text.size() - 1), text.get(text.size() - 1).replace(oldChar, newChar));
        return true;
    }


    public boolean del(int paragraphNumber) {
        if(paragraphNumber > 0 && (paragraphNumber <= this.text.size())) {
            //paragraph hier löschen.
            return true;
        }
        return false;
    }
    public boolean del() {
        //letzter paragraph hier löschen.
        return true;
    }


}
